/*!40101 SET NAMES utf8mb4 */;

/*!40101 SET SQL_MODE=''*/;

/*!40014 SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0 */;
/*!40101 SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='NO_AUTO_VALUE_ON_ZERO' */;
/*!40111 SET @OLD_SQL_NOTES=@@SQL_NOTES, SQL_NOTES=0 */;
CREATE DATABASE /*!32312 IF NOT EXISTS*/`mall4cloud_seckill` /*!40100 DEFAULT CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci */ /*!80016 DEFAULT ENCRYPTION='N' */;

USE `mall4cloud_seckill`;

/*Table structure for table `seckill` */

DROP TABLE IF EXISTS `seckill`;

CREATE TABLE `seckill` (
  `seckill_id` bigint NOT NULL AUTO_INCREMENT COMMENT '秒杀活动id',
  `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
  `seckill_name` varchar(36) DEFAULT NULL COMMENT '活动名称',
  `start_time` datetime DEFAULT NULL COMMENT '开始日期',
  `end_time` datetime DEFAULT NULL COMMENT '结束日期',
  `selected_lot` int DEFAULT NULL COMMENT '所选批次',
  `category_id` bigint DEFAULT NULL COMMENT '所选分类',
  `seckill_tag` varchar(36) DEFAULT NULL COMMENT '活动标签',
  `max_num` int DEFAULT NULL COMMENT '限购数量',
  `max_cancel_time` int DEFAULT NULL COMMENT '取消订单时间',
  `shop_id` bigint DEFAULT NULL COMMENT '店铺id',
  `is_delete` tinyint DEFAULT NULL COMMENT '0 未删除 1已删除',
  `status` tinyint DEFAULT NULL COMMENT '状态(0:失效、1:正常、2:违规下架、3:等待审核)',
  `spu_id` bigint DEFAULT NULL COMMENT '商品id',
  `seckill_total_stocks` int DEFAULT NULL COMMENT '秒杀活动剩余总库存',
  `seckill_origin_stocks` int DEFAULT NULL COMMENT '秒杀活动原始库存',
  `seckill_price` bigint DEFAULT NULL COMMENT '秒杀活动最低价',
  `replenish` int DEFAULT NULL COMMENT '补充库存 0不补充 1补充',
  PRIMARY KEY (`seckill_id`),
  KEY `key_spu_id` (`spu_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='秒杀信息';

/*Data for the table `seckill` */

/*Table structure for table `seckill_category` */

DROP TABLE IF EXISTS `seckill_category`;

CREATE TABLE `seckill_category` (
  `category_id` bigint unsigned NOT NULL AUTO_INCREMENT COMMENT '秒杀分类id',
  `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
  `name` varchar(255) NOT NULL DEFAULT '' COMMENT '分类名称',
  `seq` int DEFAULT '0' COMMENT '排序',
  PRIMARY KEY (`category_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='秒杀分类信息';

/*Data for the table `seckill_category` */

/*Table structure for table `seckill_order` */

DROP TABLE IF EXISTS `seckill_order`;

CREATE TABLE `seckill_order` (
  `seckill_order_id` bigint NOT NULL AUTO_INCREMENT COMMENT '秒杀订单id',
  `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
  `seckill_id` bigint DEFAULT NULL COMMENT '秒杀订单id',
  `user_id` bigint DEFAULT NULL COMMENT '用户id',
  `order_id` bigint DEFAULT NULL COMMENT '订单id',
  `prod_count` int DEFAULT NULL COMMENT '秒杀到的商品数量',
  `spu_id` bigint DEFAULT NULL COMMENT '商品id',
  `state` tinyint DEFAULT NULL COMMENT '-1指无效，0指待付款，1指已付款',
  `seckill_sku_id` bigint DEFAULT NULL COMMENT '秒杀到的秒杀商品sku',
  PRIMARY KEY (`seckill_order_id`),
  KEY `key_seckill_id` (`seckill_id`),
  KEY `key_user_id` (`user_id`),
  KEY `key_order_id` (`order_id`),
  KEY `key_spu_id` (`spu_id`),
  KEY `key_seckill_sku_id` (`seckill_sku_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='秒杀订单';

/*Data for the table `seckill_order` */

/*Table structure for table `seckill_sku` */

DROP TABLE IF EXISTS `seckill_sku`;

CREATE TABLE `seckill_sku` (
  `seckill_sku_id` bigint NOT NULL AUTO_INCREMENT COMMENT '秒杀活动单个skuid',
  `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
  `sku_id` bigint DEFAULT NULL COMMENT 'skuId',
  `seckill_id` bigint DEFAULT NULL COMMENT '秒杀活动id',
  `seckill_stocks` int DEFAULT NULL COMMENT '用于秒杀的库存',
  `seckill_price` bigint DEFAULT NULL COMMENT '秒杀价格',
  `seckill_origin_stocks` INT NULL COMMENT '秒杀活动原始库存',
  PRIMARY KEY (`seckill_sku_id`),
  KEY `key_sku_id` (`sku_id`),
  KEY `key_seckill_id` (`seckill_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='秒杀活动sku';

/*Data for the table `seckill_sku` */

DROP TABLE IF EXISTS `seckill_stock_point_sku`;
CREATE TABLE `seckill_stock_point_sku` (
        `seckill_stock_point_sku_id` bigint unsigned NOT NULL AUTO_INCREMENT COMMENT '库存商品关联skuid',
        `stock_point_id` bigint NOT NULL COMMENT '库存点id',
        `stock_point_type` tinyint NOT NULL COMMENT '库存点类型 1仓库 2门店',
        `sku_id` bigint DEFAULT NULL COMMENT 'sku_id',
        `seckill_sku_id` bigint DEFAULT NULL COMMENT '秒杀活动skuid',
        `status` tinyint DEFAULT '0' COMMENT '状态 1:enable, 0:disable, -1:deleted',
        `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
        `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
        `type` tinyint DEFAULT NULL COMMENT '仓库类型（0默认仓库，1区域仓库）',
        `seckill_origin_stocks` int DEFAULT NULL COMMENT '秒杀库存点原始库存',
        PRIMARY KEY (`seckill_stock_point_sku_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

/*Table structure for table `leaf_alloc` */

CREATE TABLE IF NOT EXISTS `leaf_alloc` (
  `biz_tag` varchar(128) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci NOT NULL DEFAULT '' COMMENT '区分业务',
  `max_id` bigint unsigned NOT NULL DEFAULT '1' COMMENT '该biz_tag目前所被分配的ID号段的最大值',
  `step` int NOT NULL COMMENT '每次分配的号段长度',
  `update_time` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
  `description` varchar(256) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci DEFAULT NULL COMMENT '描述',
  PRIMARY KEY (`biz_tag`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

/*Data for the table `leaf_alloc` */

insert into `leaf_alloc` (`biz_tag`, `max_id`, `step`, `description`) values
('mall4cloud-order-000','1','1000','订单id'),
('mall4cloud-order-001','1','1000','订单id'),
('mall4cloud-order-002','1','1000','订单id'),
('mall4cloud-order-003','1','1000','订单id'),
('mall4cloud-order-004','1','1000','订单id'),
('mall4cloud-order-005','1','1000','订单id'),
('mall4cloud-order-006','1','1000','订单id'),
('mall4cloud-order-007','1','1000','订单id'),
('mall4cloud-order-008','1','1000','订单id'),
('mall4cloud-order-009','1','1000','订单id'),
('mall4cloud-order-010','1','1000','订单id'),
('mall4cloud-order-011','1','1000','订单id'),
('mall4cloud-order-012','1','1000','订单id'),
('mall4cloud-order-013','1','1000','订单id'),
('mall4cloud-order-014','1','1000','订单id'),
('mall4cloud-order-015','1','1000','订单id'),
('mall4cloud-order-016','1','1000','订单id'),
('mall4cloud-order-017','1','1000','订单id'),
('mall4cloud-order-018','1','1000','订单id'),
('mall4cloud-order-019','1','1000','订单id'),
('mall4cloud-order-020','1','1000','订单id'),
('mall4cloud-order-021','1','1000','订单id'),
('mall4cloud-order-022','1','1000','订单id'),
('mall4cloud-order-023','1','1000','订单id'),
('mall4cloud-order-024','1','1000','订单id'),
('mall4cloud-order-025','1','1000','订单id'),
('mall4cloud-order-026','1','1000','订单id'),
('mall4cloud-order-027','1','1000','订单id'),
('mall4cloud-order-028','1','1000','订单id'),
('mall4cloud-order-029','1','1000','订单id'),
('mall4cloud-order-030','1','1000','订单id'),
('mall4cloud-order-031','1','1000','订单id'),
('mall4cloud-order-032','1','1000','订单id'),
('mall4cloud-order-033','1','1000','订单id'),
('mall4cloud-order-034','1','1000','订单id'),
('mall4cloud-order-035','1','1000','订单id'),
('mall4cloud-order-036','1','1000','订单id'),
('mall4cloud-order-037','1','1000','订单id'),
('mall4cloud-order-038','1','1000','订单id'),
('mall4cloud-order-039','1','1000','订单id'),
('mall4cloud-order-040','1','1000','订单id'),
('mall4cloud-order-041','1','1000','订单id'),
('mall4cloud-order-042','1','1000','订单id'),
('mall4cloud-order-043','1','1000','订单id'),
('mall4cloud-order-044','1','1000','订单id'),
('mall4cloud-order-045','1','1000','订单id'),
('mall4cloud-order-046','1','1000','订单id'),
('mall4cloud-order-047','1','1000','订单id'),
('mall4cloud-order-048','1','1000','订单id'),
('mall4cloud-order-049','1','1000','订单id'),
('mall4cloud-order-050','1','1000','订单id'),
('mall4cloud-order-051','1','1000','订单id'),
('mall4cloud-order-052','1','1000','订单id'),
('mall4cloud-order-053','1','1000','订单id'),
('mall4cloud-order-054','1','1000','订单id'),
('mall4cloud-order-055','1','1000','订单id'),
('mall4cloud-order-056','1','1000','订单id'),
('mall4cloud-order-057','1','1000','订单id'),
('mall4cloud-order-058','1','1000','订单id'),
('mall4cloud-order-059','1','1000','订单id'),
('mall4cloud-order-060','1','1000','订单id'),
('mall4cloud-order-061','1','1000','订单id'),
('mall4cloud-order-062','1','1000','订单id'),
('mall4cloud-order-063','1','1000','订单id'),
('mall4cloud-order-064','1','1000','订单id'),
('mall4cloud-order-065','1','1000','订单id'),
('mall4cloud-order-066','1','1000','订单id'),
('mall4cloud-order-067','1','1000','订单id'),
('mall4cloud-order-068','1','1000','订单id'),
('mall4cloud-order-069','1','1000','订单id'),
('mall4cloud-order-070','1','1000','订单id'),
('mall4cloud-order-071','1','1000','订单id'),
('mall4cloud-order-072','1','1000','订单id'),
('mall4cloud-order-073','1','1000','订单id'),
('mall4cloud-order-074','1','1000','订单id'),
('mall4cloud-order-075','1','1000','订单id'),
('mall4cloud-order-076','1','1000','订单id'),
('mall4cloud-order-077','1','1000','订单id'),
('mall4cloud-order-078','1','1000','订单id'),
('mall4cloud-order-079','1','1000','订单id'),
('mall4cloud-order-080','1','1000','订单id'),
('mall4cloud-order-081','1','1000','订单id'),
('mall4cloud-order-082','1','1000','订单id'),
('mall4cloud-order-083','1','1000','订单id'),
('mall4cloud-order-084','1','1000','订单id'),
('mall4cloud-order-085','1','1000','订单id'),
('mall4cloud-order-086','1','1000','订单id'),
('mall4cloud-order-087','1','1000','订单id'),
('mall4cloud-order-088','1','1000','订单id'),
('mall4cloud-order-089','1','1000','订单id'),
('mall4cloud-order-090','1','1000','订单id'),
('mall4cloud-order-091','1','1000','订单id'),
('mall4cloud-order-092','1','1000','订单id'),
('mall4cloud-order-093','1','1000','订单id'),
('mall4cloud-order-094','1','1000','订单id'),
('mall4cloud-order-095','1','1000','订单id'),
('mall4cloud-order-096','1','1000','订单id'),
('mall4cloud-order-097','1','1000','订单id'),
('mall4cloud-order-098','1','1000','订单id'),
('mall4cloud-order-099','1','1000','订单id'),
('mall4cloud-order-100','1','1000','订单id'),
('mall4cloud-order-101','1','1000','订单id'),
('mall4cloud-order-102','1','1000','订单id'),
('mall4cloud-order-103','1','1000','订单id'),
('mall4cloud-order-104','1','1000','订单id'),
('mall4cloud-order-105','1','1000','订单id'),
('mall4cloud-order-106','1','1000','订单id'),
('mall4cloud-order-107','1','1000','订单id'),
('mall4cloud-order-108','1','1000','订单id'),
('mall4cloud-order-109','1','1000','订单id'),
('mall4cloud-order-110','1','1000','订单id'),
('mall4cloud-order-111','1','1000','订单id'),
('mall4cloud-order-112','1','1000','订单id'),
('mall4cloud-order-113','1','1000','订单id'),
('mall4cloud-order-114','1','1000','订单id'),
('mall4cloud-order-115','1','1000','订单id'),
('mall4cloud-order-116','1','1000','订单id'),
('mall4cloud-order-117','1','1000','订单id'),
('mall4cloud-order-118','1','1000','订单id'),
('mall4cloud-order-119','1','1000','订单id'),
('mall4cloud-order-120','1','1000','订单id'),
('mall4cloud-order-121','1','1000','订单id'),
('mall4cloud-order-122','1','1000','订单id'),
('mall4cloud-order-123','1','1000','订单id'),
('mall4cloud-order-124','1','1000','订单id'),
('mall4cloud-order-125','1','1000','订单id'),
('mall4cloud-order-126','1','1000','订单id'),
('mall4cloud-order-127','1','1000','订单id'),
('mall4cloud-order-128','1','1000','订单id'),
('mall4cloud-order-129','1','1000','订单id'),
('mall4cloud-order-130','1','1000','订单id'),
('mall4cloud-order-131','1','1000','订单id'),
('mall4cloud-order-132','1','1000','订单id'),
('mall4cloud-order-133','1','1000','订单id'),
('mall4cloud-order-134','1','1000','订单id'),
('mall4cloud-order-135','1','1000','订单id'),
('mall4cloud-order-136','1','1000','订单id'),
('mall4cloud-order-137','1','1000','订单id'),
('mall4cloud-order-138','1','1000','订单id'),
('mall4cloud-order-139','1','1000','订单id'),
('mall4cloud-order-140','1','1000','订单id'),
('mall4cloud-order-141','1','1000','订单id'),
('mall4cloud-order-142','1','1000','订单id'),
('mall4cloud-order-143','1','1000','订单id'),
('mall4cloud-order-144','1','1000','订单id'),
('mall4cloud-order-145','1','1000','订单id'),
('mall4cloud-order-146','1','1000','订单id'),
('mall4cloud-order-147','1','1000','订单id'),
('mall4cloud-order-148','1','1000','订单id'),
('mall4cloud-order-149','1','1000','订单id'),
('mall4cloud-order-150','1','1000','订单id'),
('mall4cloud-order-151','1','1000','订单id'),
('mall4cloud-order-152','1','1000','订单id'),
('mall4cloud-order-153','1','1000','订单id'),
('mall4cloud-order-154','1','1000','订单id'),
('mall4cloud-order-155','1','1000','订单id'),
('mall4cloud-order-156','1','1000','订单id'),
('mall4cloud-order-157','1','1000','订单id'),
('mall4cloud-order-158','1','1000','订单id'),
('mall4cloud-order-159','1','1000','订单id'),
('mall4cloud-order-160','1','1000','订单id'),
('mall4cloud-order-161','1','1000','订单id'),
('mall4cloud-order-162','1','1000','订单id'),
('mall4cloud-order-163','1','1000','订单id'),
('mall4cloud-order-164','1','1000','订单id'),
('mall4cloud-order-165','1','1000','订单id'),
('mall4cloud-order-166','1','1000','订单id'),
('mall4cloud-order-167','1','1000','订单id'),
('mall4cloud-order-168','1','1000','订单id'),
('mall4cloud-order-169','1','1000','订单id'),
('mall4cloud-order-170','1','1000','订单id'),
('mall4cloud-order-171','1','1000','订单id'),
('mall4cloud-order-172','1','1000','订单id'),
('mall4cloud-order-173','1','1000','订单id'),
('mall4cloud-order-174','1','1000','订单id'),
('mall4cloud-order-175','1','1000','订单id'),
('mall4cloud-order-176','1','1000','订单id'),
('mall4cloud-order-177','1','1000','订单id'),
('mall4cloud-order-178','1','1000','订单id'),
('mall4cloud-order-179','1','1000','订单id'),
('mall4cloud-order-180','1','1000','订单id'),
('mall4cloud-order-181','1','1000','订单id'),
('mall4cloud-order-182','1','1000','订单id'),
('mall4cloud-order-183','1','1000','订单id'),
('mall4cloud-order-184','1','1000','订单id'),
('mall4cloud-order-185','1','1000','订单id'),
('mall4cloud-order-186','1','1000','订单id'),
('mall4cloud-order-187','1','1000','订单id'),
('mall4cloud-order-188','1','1000','订单id'),
('mall4cloud-order-189','1','1000','订单id'),
('mall4cloud-order-190','1','1000','订单id'),
('mall4cloud-order-191','1','1000','订单id'),
('mall4cloud-order-192','1','1000','订单id'),
('mall4cloud-order-193','1','1000','订单id'),
('mall4cloud-order-194','1','1000','订单id'),
('mall4cloud-order-195','1','1000','订单id'),
('mall4cloud-order-196','1','1000','订单id'),
('mall4cloud-order-197','1','1000','订单id'),
('mall4cloud-order-198','1','1000','订单id'),
('mall4cloud-order-199','1','1000','订单id'),
('mall4cloud-order-200','1','1000','订单id'),
('mall4cloud-order-201','1','1000','订单id'),
('mall4cloud-order-202','1','1000','订单id'),
('mall4cloud-order-203','1','1000','订单id'),
('mall4cloud-order-204','1','1000','订单id'),
('mall4cloud-order-205','1','1000','订单id'),
('mall4cloud-order-206','1','1000','订单id'),
('mall4cloud-order-207','1','1000','订单id'),
('mall4cloud-order-208','1','1000','订单id'),
('mall4cloud-order-209','1','1000','订单id'),
('mall4cloud-order-210','1','1000','订单id'),
('mall4cloud-order-211','1','1000','订单id'),
('mall4cloud-order-212','1','1000','订单id'),
('mall4cloud-order-213','1','1000','订单id'),
('mall4cloud-order-214','1','1000','订单id'),
('mall4cloud-order-215','1','1000','订单id'),
('mall4cloud-order-216','1','1000','订单id'),
('mall4cloud-order-217','1','1000','订单id'),
('mall4cloud-order-218','1','1000','订单id'),
('mall4cloud-order-219','1','1000','订单id'),
('mall4cloud-order-220','1','1000','订单id'),
('mall4cloud-order-221','1','1000','订单id'),
('mall4cloud-order-222','1','1000','订单id'),
('mall4cloud-order-223','1','1000','订单id'),
('mall4cloud-order-224','1','1000','订单id'),
('mall4cloud-order-225','1','1000','订单id'),
('mall4cloud-order-226','1','1000','订单id'),
('mall4cloud-order-227','1','1000','订单id'),
('mall4cloud-order-228','1','1000','订单id'),
('mall4cloud-order-229','1','1000','订单id'),
('mall4cloud-order-230','1','1000','订单id'),
('mall4cloud-order-231','1','1000','订单id'),
('mall4cloud-order-232','1','1000','订单id'),
('mall4cloud-order-233','1','1000','订单id'),
('mall4cloud-order-234','1','1000','订单id'),
('mall4cloud-order-235','1','1000','订单id'),
('mall4cloud-order-236','1','1000','订单id'),
('mall4cloud-order-237','1','1000','订单id'),
('mall4cloud-order-238','1','1000','订单id'),
('mall4cloud-order-239','1','1000','订单id'),
('mall4cloud-order-240','1','1000','订单id'),
('mall4cloud-order-241','1','1000','订单id'),
('mall4cloud-order-242','1','1000','订单id'),
('mall4cloud-order-243','1','1000','订单id'),
('mall4cloud-order-244','1','1000','订单id'),
('mall4cloud-order-245','1','1000','订单id'),
('mall4cloud-order-246','1','1000','订单id'),
('mall4cloud-order-247','1','1000','订单id'),
('mall4cloud-order-248','1','1000','订单id'),
('mall4cloud-order-249','1','1000','订单id'),
('mall4cloud-order-250','1','1000','订单id'),
('mall4cloud-order-251','1','1000','订单id'),
('mall4cloud-order-252','1','1000','订单id'),
('mall4cloud-order-253','1','1000','订单id'),
('mall4cloud-order-254','1','1000','订单id'),
('mall4cloud-order-255','1','1000','订单id'),
('mall4cloud-order-256','1','1000','订单id'),
('mall4cloud-order-257','1','1000','订单id'),
('mall4cloud-order-258','1','1000','订单id'),
('mall4cloud-order-259','1','1000','订单id'),
('mall4cloud-order-260','1','1000','订单id'),
('mall4cloud-order-261','1','1000','订单id'),
('mall4cloud-order-262','1','1000','订单id'),
('mall4cloud-order-263','1','1000','订单id'),
('mall4cloud-order-264','1','1000','订单id'),
('mall4cloud-order-265','1','1000','订单id'),
('mall4cloud-order-266','1','1000','订单id'),
('mall4cloud-order-267','1','1000','订单id'),
('mall4cloud-order-268','1','1000','订单id'),
('mall4cloud-order-269','1','1000','订单id'),
('mall4cloud-order-270','1','1000','订单id'),
('mall4cloud-order-271','1','1000','订单id'),
('mall4cloud-order-272','1','1000','订单id'),
('mall4cloud-order-273','1','1000','订单id'),
('mall4cloud-order-274','1','1000','订单id'),
('mall4cloud-order-275','1','1000','订单id'),
('mall4cloud-order-276','1','1000','订单id'),
('mall4cloud-order-277','1','1000','订单id'),
('mall4cloud-order-278','1','1000','订单id'),
('mall4cloud-order-279','1','1000','订单id'),
('mall4cloud-order-280','1','1000','订单id'),
('mall4cloud-order-281','1','1000','订单id'),
('mall4cloud-order-282','1','1000','订单id'),
('mall4cloud-order-283','1','1000','订单id'),
('mall4cloud-order-284','1','1000','订单id'),
('mall4cloud-order-285','1','1000','订单id'),
('mall4cloud-order-286','1','1000','订单id'),
('mall4cloud-order-287','1','1000','订单id'),
('mall4cloud-order-288','1','1000','订单id'),
('mall4cloud-order-289','1','1000','订单id'),
('mall4cloud-order-290','1','1000','订单id'),
('mall4cloud-order-291','1','1000','订单id'),
('mall4cloud-order-292','1','1000','订单id'),
('mall4cloud-order-293','1','1000','订单id'),
('mall4cloud-order-294','1','1000','订单id'),
('mall4cloud-order-295','1','1000','订单id'),
('mall4cloud-order-296','1','1000','订单id'),
('mall4cloud-order-297','1','1000','订单id'),
('mall4cloud-order-298','1','1000','订单id'),
('mall4cloud-order-299','1','1000','订单id'),
('mall4cloud-order-300','1','1000','订单id'),
('mall4cloud-order-301','1','1000','订单id'),
('mall4cloud-order-302','1','1000','订单id'),
('mall4cloud-order-303','1','1000','订单id'),
('mall4cloud-order-304','1','1000','订单id'),
('mall4cloud-order-305','1','1000','订单id'),
('mall4cloud-order-306','1','1000','订单id'),
('mall4cloud-order-307','1','1000','订单id'),
('mall4cloud-order-308','1','1000','订单id'),
('mall4cloud-order-309','1','1000','订单id'),
('mall4cloud-order-310','1','1000','订单id'),
('mall4cloud-order-311','1','1000','订单id'),
('mall4cloud-order-312','1','1000','订单id'),
('mall4cloud-order-313','1','1000','订单id'),
('mall4cloud-order-314','1','1000','订单id'),
('mall4cloud-order-315','1','1000','订单id'),
('mall4cloud-order-316','1','1000','订单id'),
('mall4cloud-order-317','1','1000','订单id'),
('mall4cloud-order-318','1','1000','订单id'),
('mall4cloud-order-319','1','1000','订单id'),
('mall4cloud-order-320','1','1000','订单id'),
('mall4cloud-order-321','1','1000','订单id'),
('mall4cloud-order-322','1','1000','订单id'),
('mall4cloud-order-323','1','1000','订单id'),
('mall4cloud-order-324','1','1000','订单id'),
('mall4cloud-order-325','1','1000','订单id'),
('mall4cloud-order-326','1','1000','订单id'),
('mall4cloud-order-327','1','1000','订单id'),
('mall4cloud-order-328','1','1000','订单id'),
('mall4cloud-order-329','1','1000','订单id'),
('mall4cloud-order-330','1','1000','订单id'),
('mall4cloud-order-331','1','1000','订单id'),
('mall4cloud-order-332','1','1000','订单id'),
('mall4cloud-order-333','1','1000','订单id'),
('mall4cloud-order-334','1','1000','订单id'),
('mall4cloud-order-335','1','1000','订单id'),
('mall4cloud-order-336','1','1000','订单id'),
('mall4cloud-order-337','1','1000','订单id'),
('mall4cloud-order-338','1','1000','订单id'),
('mall4cloud-order-339','1','1000','订单id'),
('mall4cloud-order-340','1','1000','订单id'),
('mall4cloud-order-341','1','1000','订单id'),
('mall4cloud-order-342','1','1000','订单id'),
('mall4cloud-order-343','1','1000','订单id'),
('mall4cloud-order-344','1','1000','订单id'),
('mall4cloud-order-345','1','1000','订单id'),
('mall4cloud-order-346','1','1000','订单id'),
('mall4cloud-order-347','1','1000','订单id'),
('mall4cloud-order-348','1','1000','订单id'),
('mall4cloud-order-349','1','1000','订单id'),
('mall4cloud-order-350','1','1000','订单id'),
('mall4cloud-order-351','1','1000','订单id'),
('mall4cloud-order-352','1','1000','订单id'),
('mall4cloud-order-353','1','1000','订单id'),
('mall4cloud-order-354','1','1000','订单id'),
('mall4cloud-order-355','1','1000','订单id'),
('mall4cloud-order-356','1','1000','订单id'),
('mall4cloud-order-357','1','1000','订单id'),
('mall4cloud-order-358','1','1000','订单id'),
('mall4cloud-order-359','1','1000','订单id'),
('mall4cloud-order-360','1','1000','订单id'),
('mall4cloud-order-361','1','1000','订单id'),
('mall4cloud-order-362','1','1000','订单id'),
('mall4cloud-order-363','1','1000','订单id'),
('mall4cloud-order-364','1','1000','订单id'),
('mall4cloud-order-365','1','1000','订单id'),
('mall4cloud-order-366','1','1000','订单id'),
('mall4cloud-order-367','1','1000','订单id'),
('mall4cloud-order-368','1','1000','订单id'),
('mall4cloud-order-369','1','1000','订单id'),
('mall4cloud-order-370','1','1000','订单id'),
('mall4cloud-order-371','1','1000','订单id'),
('mall4cloud-order-372','1','1000','订单id'),
('mall4cloud-order-373','1','1000','订单id'),
('mall4cloud-order-374','1','1000','订单id'),
('mall4cloud-order-375','1','1000','订单id'),
('mall4cloud-order-376','1','1000','订单id'),
('mall4cloud-order-377','1','1000','订单id'),
('mall4cloud-order-378','1','1000','订单id'),
('mall4cloud-order-379','1','1000','订单id'),
('mall4cloud-order-380','1','1000','订单id'),
('mall4cloud-order-381','1','1000','订单id'),
('mall4cloud-order-382','1','1000','订单id'),
('mall4cloud-order-383','1','1000','订单id'),
('mall4cloud-order-384','1','1000','订单id'),
('mall4cloud-order-385','1','1000','订单id'),
('mall4cloud-order-386','1','1000','订单id'),
('mall4cloud-order-387','1','1000','订单id'),
('mall4cloud-order-388','1','1000','订单id'),
('mall4cloud-order-389','1','1000','订单id'),
('mall4cloud-order-390','1','1000','订单id'),
('mall4cloud-order-391','1','1000','订单id'),
('mall4cloud-order-392','1','1000','订单id'),
('mall4cloud-order-393','1','1000','订单id'),
('mall4cloud-order-394','1','1000','订单id'),
('mall4cloud-order-395','1','1000','订单id'),
('mall4cloud-order-396','1','1000','订单id'),
('mall4cloud-order-397','1','1000','订单id'),
('mall4cloud-order-398','1','1000','订单id'),
('mall4cloud-order-399','1','1000','订单id'),
('mall4cloud-order-400','1','1000','订单id'),
('mall4cloud-order-401','1','1000','订单id'),
('mall4cloud-order-402','1','1000','订单id'),
('mall4cloud-order-403','1','1000','订单id'),
('mall4cloud-order-404','1','1000','订单id'),
('mall4cloud-order-405','1','1000','订单id'),
('mall4cloud-order-406','1','1000','订单id'),
('mall4cloud-order-407','1','1000','订单id'),
('mall4cloud-order-408','1','1000','订单id'),
('mall4cloud-order-409','1','1000','订单id'),
('mall4cloud-order-410','1','1000','订单id'),
('mall4cloud-order-411','1','1000','订单id'),
('mall4cloud-order-412','1','1000','订单id'),
('mall4cloud-order-413','1','1000','订单id'),
('mall4cloud-order-414','1','1000','订单id'),
('mall4cloud-order-415','1','1000','订单id'),
('mall4cloud-order-416','1','1000','订单id'),
('mall4cloud-order-417','1','1000','订单id'),
('mall4cloud-order-418','1','1000','订单id'),
('mall4cloud-order-419','1','1000','订单id'),
('mall4cloud-order-420','1','1000','订单id'),
('mall4cloud-order-421','1','1000','订单id'),
('mall4cloud-order-422','1','1000','订单id'),
('mall4cloud-order-423','1','1000','订单id'),
('mall4cloud-order-424','1','1000','订单id'),
('mall4cloud-order-425','1','1000','订单id'),
('mall4cloud-order-426','1','1000','订单id'),
('mall4cloud-order-427','1','1000','订单id'),
('mall4cloud-order-428','1','1000','订单id'),
('mall4cloud-order-429','1','1000','订单id'),
('mall4cloud-order-430','1','1000','订单id'),
('mall4cloud-order-431','1','1000','订单id'),
('mall4cloud-order-432','1','1000','订单id'),
('mall4cloud-order-433','1','1000','订单id'),
('mall4cloud-order-434','1','1000','订单id'),
('mall4cloud-order-435','1','1000','订单id'),
('mall4cloud-order-436','1','1000','订单id'),
('mall4cloud-order-437','1','1000','订单id'),
('mall4cloud-order-438','1','1000','订单id'),
('mall4cloud-order-439','1','1000','订单id'),
('mall4cloud-order-440','1','1000','订单id'),
('mall4cloud-order-441','1','1000','订单id'),
('mall4cloud-order-442','1','1000','订单id'),
('mall4cloud-order-443','1','1000','订单id'),
('mall4cloud-order-444','1','1000','订单id'),
('mall4cloud-order-445','1','1000','订单id'),
('mall4cloud-order-446','1','1000','订单id'),
('mall4cloud-order-447','1','1000','订单id'),
('mall4cloud-order-448','1','1000','订单id'),
('mall4cloud-order-449','1','1000','订单id'),
('mall4cloud-order-450','1','1000','订单id'),
('mall4cloud-order-451','1','1000','订单id'),
('mall4cloud-order-452','1','1000','订单id'),
('mall4cloud-order-453','1','1000','订单id'),
('mall4cloud-order-454','1','1000','订单id'),
('mall4cloud-order-455','1','1000','订单id'),
('mall4cloud-order-456','1','1000','订单id'),
('mall4cloud-order-457','1','1000','订单id'),
('mall4cloud-order-458','1','1000','订单id'),
('mall4cloud-order-459','1','1000','订单id'),
('mall4cloud-order-460','1','1000','订单id'),
('mall4cloud-order-461','1','1000','订单id'),
('mall4cloud-order-462','1','1000','订单id'),
('mall4cloud-order-463','1','1000','订单id'),
('mall4cloud-order-464','1','1000','订单id'),
('mall4cloud-order-465','1','1000','订单id'),
('mall4cloud-order-466','1','1000','订单id'),
('mall4cloud-order-467','1','1000','订单id'),
('mall4cloud-order-468','1','1000','订单id'),
('mall4cloud-order-469','1','1000','订单id'),
('mall4cloud-order-470','1','1000','订单id'),
('mall4cloud-order-471','1','1000','订单id'),
('mall4cloud-order-472','1','1000','订单id'),
('mall4cloud-order-473','1','1000','订单id'),
('mall4cloud-order-474','1','1000','订单id'),
('mall4cloud-order-475','1','1000','订单id'),
('mall4cloud-order-476','1','1000','订单id'),
('mall4cloud-order-477','1','1000','订单id'),
('mall4cloud-order-478','1','1000','订单id'),
('mall4cloud-order-479','1','1000','订单id'),
('mall4cloud-order-480','1','1000','订单id'),
('mall4cloud-order-481','1','1000','订单id'),
('mall4cloud-order-482','1','1000','订单id'),
('mall4cloud-order-483','1','1000','订单id'),
('mall4cloud-order-484','1','1000','订单id'),
('mall4cloud-order-485','1','1000','订单id'),
('mall4cloud-order-486','1','1000','订单id'),
('mall4cloud-order-487','1','1000','订单id'),
('mall4cloud-order-488','1','1000','订单id'),
('mall4cloud-order-489','1','1000','订单id'),
('mall4cloud-order-490','1','1000','订单id'),
('mall4cloud-order-491','1','1000','订单id'),
('mall4cloud-order-492','1','1000','订单id'),
('mall4cloud-order-493','1','1000','订单id'),
('mall4cloud-order-494','1','1000','订单id'),
('mall4cloud-order-495','1','1000','订单id'),
('mall4cloud-order-496','1','1000','订单id'),
('mall4cloud-order-497','1','1000','订单id'),
('mall4cloud-order-498','1','1000','订单id'),
('mall4cloud-order-499','1','1000','订单id'),
('mall4cloud-order-500','1','1000','订单id'),
('mall4cloud-order-501','1','1000','订单id'),
('mall4cloud-order-502','1','1000','订单id'),
('mall4cloud-order-503','1','1000','订单id'),
('mall4cloud-order-504','1','1000','订单id'),
('mall4cloud-order-505','1','1000','订单id'),
('mall4cloud-order-506','1','1000','订单id'),
('mall4cloud-order-507','1','1000','订单id'),
('mall4cloud-order-508','1','1000','订单id'),
('mall4cloud-order-509','1','1000','订单id'),
('mall4cloud-order-510','1','1000','订单id'),
('mall4cloud-order-511','1','1000','订单id'),
('mall4cloud-order-512','1','1000','订单id'),
('mall4cloud-order-513','1','1000','订单id'),
('mall4cloud-order-514','1','1000','订单id'),
('mall4cloud-order-515','1','1000','订单id'),
('mall4cloud-order-516','1','1000','订单id'),
('mall4cloud-order-517','1','1000','订单id'),
('mall4cloud-order-518','1','1000','订单id'),
('mall4cloud-order-519','1','1000','订单id'),
('mall4cloud-order-520','1','1000','订单id'),
('mall4cloud-order-521','1','1000','订单id'),
('mall4cloud-order-522','1','1000','订单id'),
('mall4cloud-order-523','1','1000','订单id'),
('mall4cloud-order-524','1','1000','订单id'),
('mall4cloud-order-525','1','1000','订单id'),
('mall4cloud-order-526','1','1000','订单id'),
('mall4cloud-order-527','1','1000','订单id'),
('mall4cloud-order-528','1','1000','订单id'),
('mall4cloud-order-529','1','1000','订单id'),
('mall4cloud-order-530','1','1000','订单id'),
('mall4cloud-order-531','1','1000','订单id'),
('mall4cloud-order-532','1','1000','订单id'),
('mall4cloud-order-533','1','1000','订单id'),
('mall4cloud-order-534','1','1000','订单id'),
('mall4cloud-order-535','1','1000','订单id'),
('mall4cloud-order-536','1','1000','订单id'),
('mall4cloud-order-537','1','1000','订单id'),
('mall4cloud-order-538','1','1000','订单id'),
('mall4cloud-order-539','1','1000','订单id'),
('mall4cloud-order-540','1','1000','订单id'),
('mall4cloud-order-541','1','1000','订单id'),
('mall4cloud-order-542','1','1000','订单id'),
('mall4cloud-order-543','1','1000','订单id'),
('mall4cloud-order-544','1','1000','订单id'),
('mall4cloud-order-545','1','1000','订单id'),
('mall4cloud-order-546','1','1000','订单id'),
('mall4cloud-order-547','1','1000','订单id'),
('mall4cloud-order-548','1','1000','订单id'),
('mall4cloud-order-549','1','1000','订单id'),
('mall4cloud-order-550','1','1000','订单id'),
('mall4cloud-order-551','1','1000','订单id'),
('mall4cloud-order-552','1','1000','订单id'),
('mall4cloud-order-553','1','1000','订单id'),
('mall4cloud-order-554','1','1000','订单id'),
('mall4cloud-order-555','1','1000','订单id'),
('mall4cloud-order-556','1','1000','订单id'),
('mall4cloud-order-557','1','1000','订单id'),
('mall4cloud-order-558','1','1000','订单id'),
('mall4cloud-order-559','1','1000','订单id'),
('mall4cloud-order-560','1','1000','订单id'),
('mall4cloud-order-561','1','1000','订单id'),
('mall4cloud-order-562','1','1000','订单id'),
('mall4cloud-order-563','1','1000','订单id'),
('mall4cloud-order-564','1','1000','订单id'),
('mall4cloud-order-565','1','1000','订单id'),
('mall4cloud-order-566','1','1000','订单id'),
('mall4cloud-order-567','1','1000','订单id'),
('mall4cloud-order-568','1','1000','订单id'),
('mall4cloud-order-569','1','1000','订单id'),
('mall4cloud-order-570','1','1000','订单id'),
('mall4cloud-order-571','1','1000','订单id'),
('mall4cloud-order-572','1','1000','订单id'),
('mall4cloud-order-573','1','1000','订单id'),
('mall4cloud-order-574','1','1000','订单id'),
('mall4cloud-order-575','1','1000','订单id'),
('mall4cloud-order-576','1','1000','订单id'),
('mall4cloud-order-577','1','1000','订单id'),
('mall4cloud-order-578','1','1000','订单id'),
('mall4cloud-order-579','1','1000','订单id'),
('mall4cloud-order-580','1','1000','订单id'),
('mall4cloud-order-581','1','1000','订单id'),
('mall4cloud-order-582','1','1000','订单id'),
('mall4cloud-order-583','1','1000','订单id'),
('mall4cloud-order-584','1','1000','订单id'),
('mall4cloud-order-585','1','1000','订单id'),
('mall4cloud-order-586','1','1000','订单id'),
('mall4cloud-order-587','1','1000','订单id'),
('mall4cloud-order-588','1','1000','订单id'),
('mall4cloud-order-589','1','1000','订单id'),
('mall4cloud-order-590','1','1000','订单id'),
('mall4cloud-order-591','1','1000','订单id'),
('mall4cloud-order-592','1','1000','订单id'),
('mall4cloud-order-593','1','1000','订单id'),
('mall4cloud-order-594','1','1000','订单id'),
('mall4cloud-order-595','1','1000','订单id'),
('mall4cloud-order-596','1','1000','订单id'),
('mall4cloud-order-597','1','1000','订单id'),
('mall4cloud-order-598','1','1000','订单id'),
('mall4cloud-order-599','1','1000','订单id'),
('mall4cloud-order-600','1','1000','订单id'),
('mall4cloud-order-601','1','1000','订单id'),
('mall4cloud-order-602','1','1000','订单id'),
('mall4cloud-order-603','1','1000','订单id'),
('mall4cloud-order-604','1','1000','订单id'),
('mall4cloud-order-605','1','1000','订单id'),
('mall4cloud-order-606','1','1000','订单id'),
('mall4cloud-order-607','1','1000','订单id'),
('mall4cloud-order-608','1','1000','订单id'),
('mall4cloud-order-609','1','1000','订单id'),
('mall4cloud-order-610','1','1000','订单id'),
('mall4cloud-order-611','1','1000','订单id'),
('mall4cloud-order-612','1','1000','订单id'),
('mall4cloud-order-613','1','1000','订单id'),
('mall4cloud-order-614','1','1000','订单id'),
('mall4cloud-order-615','1','1000','订单id'),
('mall4cloud-order-616','1','1000','订单id'),
('mall4cloud-order-617','1','1000','订单id'),
('mall4cloud-order-618','1','1000','订单id'),
('mall4cloud-order-619','1','1000','订单id'),
('mall4cloud-order-620','1','1000','订单id'),
('mall4cloud-order-621','1','1000','订单id'),
('mall4cloud-order-622','1','1000','订单id'),
('mall4cloud-order-623','1','1000','订单id'),
('mall4cloud-order-624','1','1000','订单id'),
('mall4cloud-order-625','1','1000','订单id'),
('mall4cloud-order-626','1','1000','订单id'),
('mall4cloud-order-627','1','1000','订单id'),
('mall4cloud-order-628','1','1000','订单id'),
('mall4cloud-order-629','1','1000','订单id'),
('mall4cloud-order-630','1','1000','订单id'),
('mall4cloud-order-631','1','1000','订单id'),
('mall4cloud-order-632','1','1000','订单id'),
('mall4cloud-order-633','1','1000','订单id'),
('mall4cloud-order-634','1','1000','订单id'),
('mall4cloud-order-635','1','1000','订单id'),
('mall4cloud-order-636','1','1000','订单id'),
('mall4cloud-order-637','1','1000','订单id'),
('mall4cloud-order-638','1','1000','订单id'),
('mall4cloud-order-639','1','1000','订单id'),
('mall4cloud-order-640','1','1000','订单id'),
('mall4cloud-order-641','1','1000','订单id'),
('mall4cloud-order-642','1','1000','订单id'),
('mall4cloud-order-643','1','1000','订单id'),
('mall4cloud-order-644','1','1000','订单id'),
('mall4cloud-order-645','1','1000','订单id'),
('mall4cloud-order-646','1','1000','订单id'),
('mall4cloud-order-647','1','1000','订单id'),
('mall4cloud-order-648','1','1000','订单id'),
('mall4cloud-order-649','1','1000','订单id'),
('mall4cloud-order-650','1','1000','订单id'),
('mall4cloud-order-651','1','1000','订单id'),
('mall4cloud-order-652','1','1000','订单id'),
('mall4cloud-order-653','1','1000','订单id'),
('mall4cloud-order-654','1','1000','订单id'),
('mall4cloud-order-655','1','1000','订单id'),
('mall4cloud-order-656','1','1000','订单id'),
('mall4cloud-order-657','1','1000','订单id'),
('mall4cloud-order-658','1','1000','订单id'),
('mall4cloud-order-659','1','1000','订单id'),
('mall4cloud-order-660','1','1000','订单id'),
('mall4cloud-order-661','1','1000','订单id'),
('mall4cloud-order-662','1','1000','订单id'),
('mall4cloud-order-663','1','1000','订单id'),
('mall4cloud-order-664','1','1000','订单id'),
('mall4cloud-order-665','1','1000','订单id'),
('mall4cloud-order-666','1','1000','订单id'),
('mall4cloud-order-667','1','1000','订单id'),
('mall4cloud-order-668','1','1000','订单id'),
('mall4cloud-order-669','1','1000','订单id'),
('mall4cloud-order-670','1','1000','订单id'),
('mall4cloud-order-671','1','1000','订单id'),
('mall4cloud-order-672','1','1000','订单id'),
('mall4cloud-order-673','1','1000','订单id'),
('mall4cloud-order-674','1','1000','订单id'),
('mall4cloud-order-675','1','1000','订单id'),
('mall4cloud-order-676','1','1000','订单id'),
('mall4cloud-order-677','1','1000','订单id'),
('mall4cloud-order-678','1','1000','订单id'),
('mall4cloud-order-679','1','1000','订单id'),
('mall4cloud-order-680','1','1000','订单id'),
('mall4cloud-order-681','1','1000','订单id'),
('mall4cloud-order-682','1','1000','订单id'),
('mall4cloud-order-683','1','1000','订单id'),
('mall4cloud-order-684','1','1000','订单id'),
('mall4cloud-order-685','1','1000','订单id'),
('mall4cloud-order-686','1','1000','订单id'),
('mall4cloud-order-687','1','1000','订单id'),
('mall4cloud-order-688','1','1000','订单id'),
('mall4cloud-order-689','1','1000','订单id'),
('mall4cloud-order-690','1','1000','订单id'),
('mall4cloud-order-691','1','1000','订单id'),
('mall4cloud-order-692','1','1000','订单id'),
('mall4cloud-order-693','1','1000','订单id'),
('mall4cloud-order-694','1','1000','订单id'),
('mall4cloud-order-695','1','1000','订单id'),
('mall4cloud-order-696','1','1000','订单id'),
('mall4cloud-order-697','1','1000','订单id'),
('mall4cloud-order-698','1','1000','订单id'),
('mall4cloud-order-699','1','1000','订单id'),
('mall4cloud-order-700','1','1000','订单id'),
('mall4cloud-order-701','1','1000','订单id'),
('mall4cloud-order-702','1','1000','订单id'),
('mall4cloud-order-703','1','1000','订单id'),
('mall4cloud-order-704','1','1000','订单id'),
('mall4cloud-order-705','1','1000','订单id'),
('mall4cloud-order-706','1','1000','订单id'),
('mall4cloud-order-707','1','1000','订单id'),
('mall4cloud-order-708','1','1000','订单id'),
('mall4cloud-order-709','1','1000','订单id'),
('mall4cloud-order-710','1','1000','订单id'),
('mall4cloud-order-711','1','1000','订单id'),
('mall4cloud-order-712','1','1000','订单id'),
('mall4cloud-order-713','1','1000','订单id'),
('mall4cloud-order-714','1','1000','订单id'),
('mall4cloud-order-715','1','1000','订单id'),
('mall4cloud-order-716','1','1000','订单id'),
('mall4cloud-order-717','1','1000','订单id'),
('mall4cloud-order-718','1','1000','订单id'),
('mall4cloud-order-719','1','1000','订单id'),
('mall4cloud-order-720','1','1000','订单id'),
('mall4cloud-order-721','1','1000','订单id'),
('mall4cloud-order-722','1','1000','订单id'),
('mall4cloud-order-723','1','1000','订单id'),
('mall4cloud-order-724','1','1000','订单id'),
('mall4cloud-order-725','1','1000','订单id'),
('mall4cloud-order-726','1','1000','订单id'),
('mall4cloud-order-727','1','1000','订单id'),
('mall4cloud-order-728','1','1000','订单id'),
('mall4cloud-order-729','1','1000','订单id'),
('mall4cloud-order-730','1','1000','订单id'),
('mall4cloud-order-731','1','1000','订单id'),
('mall4cloud-order-732','1','1000','订单id'),
('mall4cloud-order-733','1','1000','订单id'),
('mall4cloud-order-734','1','1000','订单id'),
('mall4cloud-order-735','1','1000','订单id'),
('mall4cloud-order-736','1','1000','订单id'),
('mall4cloud-order-737','1','1000','订单id'),
('mall4cloud-order-738','1','1000','订单id'),
('mall4cloud-order-739','1','1000','订单id'),
('mall4cloud-order-740','1','1000','订单id'),
('mall4cloud-order-741','1','1000','订单id'),
('mall4cloud-order-742','1','1000','订单id'),
('mall4cloud-order-743','1','1000','订单id'),
('mall4cloud-order-744','1','1000','订单id'),
('mall4cloud-order-745','1','1000','订单id'),
('mall4cloud-order-746','1','1000','订单id'),
('mall4cloud-order-747','1','1000','订单id'),
('mall4cloud-order-748','1','1000','订单id'),
('mall4cloud-order-749','1','1000','订单id'),
('mall4cloud-order-750','1','1000','订单id'),
('mall4cloud-order-751','1','1000','订单id'),
('mall4cloud-order-752','1','1000','订单id'),
('mall4cloud-order-753','1','1000','订单id'),
('mall4cloud-order-754','1','1000','订单id'),
('mall4cloud-order-755','1','1000','订单id'),
('mall4cloud-order-756','1','1000','订单id'),
('mall4cloud-order-757','1','1000','订单id'),
('mall4cloud-order-758','1','1000','订单id'),
('mall4cloud-order-759','1','1000','订单id'),
('mall4cloud-order-760','1','1000','订单id'),
('mall4cloud-order-761','1','1000','订单id'),
('mall4cloud-order-762','1','1000','订单id'),
('mall4cloud-order-763','1','1000','订单id'),
('mall4cloud-order-764','1','1000','订单id'),
('mall4cloud-order-765','1','1000','订单id'),
('mall4cloud-order-766','1','1000','订单id'),
('mall4cloud-order-767','1','1000','订单id'),
('mall4cloud-order-768','1','1000','订单id'),
('mall4cloud-order-769','1','1000','订单id'),
('mall4cloud-order-770','1','1000','订单id'),
('mall4cloud-order-771','1','1000','订单id'),
('mall4cloud-order-772','1','1000','订单id'),
('mall4cloud-order-773','1','1000','订单id'),
('mall4cloud-order-774','1','1000','订单id'),
('mall4cloud-order-775','1','1000','订单id'),
('mall4cloud-order-776','1','1000','订单id'),
('mall4cloud-order-777','1','1000','订单id'),
('mall4cloud-order-778','1','1000','订单id'),
('mall4cloud-order-779','1','1000','订单id'),
('mall4cloud-order-780','1','1000','订单id'),
('mall4cloud-order-781','1','1000','订单id'),
('mall4cloud-order-782','1','1000','订单id'),
('mall4cloud-order-783','1','1000','订单id'),
('mall4cloud-order-784','1','1000','订单id'),
('mall4cloud-order-785','1','1000','订单id'),
('mall4cloud-order-786','1','1000','订单id'),
('mall4cloud-order-787','1','1000','订单id'),
('mall4cloud-order-788','1','1000','订单id'),
('mall4cloud-order-789','1','1000','订单id'),
('mall4cloud-order-790','1','1000','订单id'),
('mall4cloud-order-791','1','1000','订单id'),
('mall4cloud-order-792','1','1000','订单id'),
('mall4cloud-order-793','1','1000','订单id'),
('mall4cloud-order-794','1','1000','订单id'),
('mall4cloud-order-795','1','1000','订单id'),
('mall4cloud-order-796','1','1000','订单id'),
('mall4cloud-order-797','1','1000','订单id'),
('mall4cloud-order-798','1','1000','订单id'),
('mall4cloud-order-799','1','1000','订单id'),
('mall4cloud-order-800','1','1000','订单id'),
('mall4cloud-order-801','1','1000','订单id'),
('mall4cloud-order-802','1','1000','订单id'),
('mall4cloud-order-803','1','1000','订单id'),
('mall4cloud-order-804','1','1000','订单id'),
('mall4cloud-order-805','1','1000','订单id'),
('mall4cloud-order-806','1','1000','订单id'),
('mall4cloud-order-807','1','1000','订单id'),
('mall4cloud-order-808','1','1000','订单id'),
('mall4cloud-order-809','1','1000','订单id'),
('mall4cloud-order-810','1','1000','订单id'),
('mall4cloud-order-811','1','1000','订单id'),
('mall4cloud-order-812','1','1000','订单id'),
('mall4cloud-order-813','1','1000','订单id'),
('mall4cloud-order-814','1','1000','订单id'),
('mall4cloud-order-815','1','1000','订单id'),
('mall4cloud-order-816','1','1000','订单id'),
('mall4cloud-order-817','1','1000','订单id'),
('mall4cloud-order-818','1','1000','订单id'),
('mall4cloud-order-819','1','1000','订单id'),
('mall4cloud-order-820','1','1000','订单id'),
('mall4cloud-order-821','1','1000','订单id'),
('mall4cloud-order-822','1','1000','订单id'),
('mall4cloud-order-823','1','1000','订单id'),
('mall4cloud-order-824','1','1000','订单id'),
('mall4cloud-order-825','1','1000','订单id'),
('mall4cloud-order-826','1','1000','订单id'),
('mall4cloud-order-827','1','1000','订单id'),
('mall4cloud-order-828','1','1000','订单id'),
('mall4cloud-order-829','1','1000','订单id'),
('mall4cloud-order-830','1','1000','订单id'),
('mall4cloud-order-831','1','1000','订单id'),
('mall4cloud-order-832','1','1000','订单id'),
('mall4cloud-order-833','1','1000','订单id'),
('mall4cloud-order-834','1','1000','订单id'),
('mall4cloud-order-835','1','1000','订单id'),
('mall4cloud-order-836','1','1000','订单id'),
('mall4cloud-order-837','1','1000','订单id'),
('mall4cloud-order-838','1','1000','订单id'),
('mall4cloud-order-839','1','1000','订单id'),
('mall4cloud-order-840','1','1000','订单id'),
('mall4cloud-order-841','1','1000','订单id'),
('mall4cloud-order-842','1','1000','订单id'),
('mall4cloud-order-843','1','1000','订单id'),
('mall4cloud-order-844','1','1000','订单id'),
('mall4cloud-order-845','1','1000','订单id'),
('mall4cloud-order-846','1','1000','订单id'),
('mall4cloud-order-847','1','1000','订单id'),
('mall4cloud-order-848','1','1000','订单id'),
('mall4cloud-order-849','1','1000','订单id'),
('mall4cloud-order-850','1','1000','订单id'),
('mall4cloud-order-851','1','1000','订单id'),
('mall4cloud-order-852','1','1000','订单id'),
('mall4cloud-order-853','1','1000','订单id'),
('mall4cloud-order-854','1','1000','订单id'),
('mall4cloud-order-855','1','1000','订单id'),
('mall4cloud-order-856','1','1000','订单id'),
('mall4cloud-order-857','1','1000','订单id'),
('mall4cloud-order-858','1','1000','订单id'),
('mall4cloud-order-859','1','1000','订单id'),
('mall4cloud-order-860','1','1000','订单id'),
('mall4cloud-order-861','1','1000','订单id'),
('mall4cloud-order-862','1','1000','订单id'),
('mall4cloud-order-863','1','1000','订单id'),
('mall4cloud-order-864','1','1000','订单id'),
('mall4cloud-order-865','1','1000','订单id'),
('mall4cloud-order-866','1','1000','订单id'),
('mall4cloud-order-867','1','1000','订单id'),
('mall4cloud-order-868','1','1000','订单id'),
('mall4cloud-order-869','1','1000','订单id'),
('mall4cloud-order-870','1','1000','订单id'),
('mall4cloud-order-871','1','1000','订单id'),
('mall4cloud-order-872','1','1000','订单id'),
('mall4cloud-order-873','1','1000','订单id'),
('mall4cloud-order-874','1','1000','订单id'),
('mall4cloud-order-875','1','1000','订单id'),
('mall4cloud-order-876','1','1000','订单id'),
('mall4cloud-order-877','1','1000','订单id'),
('mall4cloud-order-878','1','1000','订单id'),
('mall4cloud-order-879','1','1000','订单id'),
('mall4cloud-order-880','1','1000','订单id'),
('mall4cloud-order-881','1','1000','订单id'),
('mall4cloud-order-882','1','1000','订单id'),
('mall4cloud-order-883','1','1000','订单id'),
('mall4cloud-order-884','1','1000','订单id'),
('mall4cloud-order-885','1','1000','订单id'),
('mall4cloud-order-886','1','1000','订单id'),
('mall4cloud-order-887','1','1000','订单id'),
('mall4cloud-order-888','1','1000','订单id'),
('mall4cloud-order-889','1','1000','订单id'),
('mall4cloud-order-890','1','1000','订单id'),
('mall4cloud-order-891','1','1000','订单id'),
('mall4cloud-order-892','1','1000','订单id'),
('mall4cloud-order-893','1','1000','订单id'),
('mall4cloud-order-894','1','1000','订单id'),
('mall4cloud-order-895','1','1000','订单id'),
('mall4cloud-order-896','1','1000','订单id'),
('mall4cloud-order-897','1','1000','订单id'),
('mall4cloud-order-898','1','1000','订单id'),
('mall4cloud-order-899','1','1000','订单id'),
('mall4cloud-order-900','1','1000','订单id'),
('mall4cloud-order-901','1','1000','订单id'),
('mall4cloud-order-902','1','1000','订单id'),
('mall4cloud-order-903','1','1000','订单id'),
('mall4cloud-order-904','1','1000','订单id'),
('mall4cloud-order-905','1','1000','订单id'),
('mall4cloud-order-906','1','1000','订单id'),
('mall4cloud-order-907','1','1000','订单id'),
('mall4cloud-order-908','1','1000','订单id'),
('mall4cloud-order-909','1','1000','订单id'),
('mall4cloud-order-910','1','1000','订单id'),
('mall4cloud-order-911','1','1000','订单id'),
('mall4cloud-order-912','1','1000','订单id'),
('mall4cloud-order-913','1','1000','订单id'),
('mall4cloud-order-914','1','1000','订单id'),
('mall4cloud-order-915','1','1000','订单id'),
('mall4cloud-order-916','1','1000','订单id'),
('mall4cloud-order-917','1','1000','订单id'),
('mall4cloud-order-918','1','1000','订单id'),
('mall4cloud-order-919','1','1000','订单id'),
('mall4cloud-order-920','1','1000','订单id'),
('mall4cloud-order-921','1','1000','订单id'),
('mall4cloud-order-922','1','1000','订单id'),
('mall4cloud-order-923','1','1000','订单id'),
('mall4cloud-order-924','1','1000','订单id'),
('mall4cloud-order-925','1','1000','订单id'),
('mall4cloud-order-926','1','1000','订单id'),
('mall4cloud-order-927','1','1000','订单id'),
('mall4cloud-order-928','1','1000','订单id'),
('mall4cloud-order-929','1','1000','订单id'),
('mall4cloud-order-930','1','1000','订单id'),
('mall4cloud-order-931','1','1000','订单id'),
('mall4cloud-order-932','1','1000','订单id'),
('mall4cloud-order-933','1','1000','订单id'),
('mall4cloud-order-934','1','1000','订单id'),
('mall4cloud-order-935','1','1000','订单id'),
('mall4cloud-order-936','1','1000','订单id'),
('mall4cloud-order-937','1','1000','订单id'),
('mall4cloud-order-938','1','1000','订单id'),
('mall4cloud-order-939','1','1000','订单id'),
('mall4cloud-order-940','1','1000','订单id'),
('mall4cloud-order-941','1','1000','订单id'),
('mall4cloud-order-942','1','1000','订单id'),
('mall4cloud-order-943','1','1000','订单id'),
('mall4cloud-order-944','1','1000','订单id'),
('mall4cloud-order-945','1','1000','订单id'),
('mall4cloud-order-946','1','1000','订单id'),
('mall4cloud-order-947','1','1000','订单id'),
('mall4cloud-order-948','1','1000','订单id'),
('mall4cloud-order-949','1','1000','订单id'),
('mall4cloud-order-950','1','1000','订单id'),
('mall4cloud-order-951','1','1000','订单id'),
('mall4cloud-order-952','1','1000','订单id'),
('mall4cloud-order-953','1','1000','订单id'),
('mall4cloud-order-954','1','1000','订单id'),
('mall4cloud-order-955','1','1000','订单id'),
('mall4cloud-order-956','1','1000','订单id'),
('mall4cloud-order-957','1','1000','订单id'),
('mall4cloud-order-958','1','1000','订单id'),
('mall4cloud-order-959','1','1000','订单id'),
('mall4cloud-order-960','1','1000','订单id'),
('mall4cloud-order-961','1','1000','订单id'),
('mall4cloud-order-962','1','1000','订单id'),
('mall4cloud-order-963','1','1000','订单id'),
('mall4cloud-order-964','1','1000','订单id'),
('mall4cloud-order-965','1','1000','订单id'),
('mall4cloud-order-966','1','1000','订单id'),
('mall4cloud-order-967','1','1000','订单id'),
('mall4cloud-order-968','1','1000','订单id'),
('mall4cloud-order-969','1','1000','订单id'),
('mall4cloud-order-970','1','1000','订单id'),
('mall4cloud-order-971','1','1000','订单id'),
('mall4cloud-order-972','1','1000','订单id'),
('mall4cloud-order-973','1','1000','订单id'),
('mall4cloud-order-974','1','1000','订单id'),
('mall4cloud-order-975','1','1000','订单id'),
('mall4cloud-order-976','1','1000','订单id'),
('mall4cloud-order-977','1','1000','订单id'),
('mall4cloud-order-978','1','1000','订单id'),
('mall4cloud-order-979','1','1000','订单id'),
('mall4cloud-order-980','1','1000','订单id'),
('mall4cloud-order-981','1','1000','订单id'),
('mall4cloud-order-982','1','1000','订单id'),
('mall4cloud-order-983','1','1000','订单id'),
('mall4cloud-order-984','1','1000','订单id'),
('mall4cloud-order-985','1','1000','订单id'),
('mall4cloud-order-986','1','1000','订单id'),
('mall4cloud-order-987','1','1000','订单id'),
('mall4cloud-order-988','1','1000','订单id'),
('mall4cloud-order-989','1','1000','订单id'),
('mall4cloud-order-990','1','1000','订单id'),
('mall4cloud-order-991','1','1000','订单id'),
('mall4cloud-order-992','1','1000','订单id'),
('mall4cloud-order-993','1','1000','订单id'),
('mall4cloud-order-994','1','1000','订单id'),
('mall4cloud-order-995','1','1000','订单id'),
('mall4cloud-order-996','1','1000','订单id'),
('mall4cloud-order-997','1','1000','订单id'),
('mall4cloud-order-998','1','1000','订单id'),
('mall4cloud-order-999','1','1000','订单id');



/*Table structure for table `undo_log` */

DROP TABLE IF EXISTS `undo_log`;

CREATE TABLE `undo_log` (
  `id` bigint NOT NULL AUTO_INCREMENT,
  `branch_id` bigint NOT NULL,
  `xid` varchar(100)  NOT NULL,
  `context` varchar(128)  NOT NULL,
  `rollback_info` longblob NOT NULL,
  `log_status` int NOT NULL,
  `log_created` datetime NOT NULL,
  `log_modified` datetime NOT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `ux_undo_log` (`xid`,`branch_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

/*Data for the table `undo_log` */

/*!40101 SET SQL_MODE=@OLD_SQL_MODE */;
/*!40014 SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS */;
/*!40111 SET SQL_NOTES=@OLD_SQL_NOTES */;
