
商品搜索 mapping

PUT product

```json
{
  "mappings" : {
    "properties" : {
      "spuId" : {
        "type" : "long"
      },
      "spuNameZh" : {
        "type" : "text",
        "analyzer" : "ik_max_word",
        "search_analyzer" : "ik_smart"
      },
      "spuNameLikeZh" : {
        "type" : "wildcard"
      },
      "spuNameEn" : {
        "type" : "text",
        "analyzer" : "ik_max_word",
        "search_analyzer" : "ik_smart"
      },
      "spuNameLikeEn" : {
        "type" : "wildcard"
      },
      "deliveryMode": {
        "type": "nested",
        "properties": {
          "hasUserPickUp": {
            "type": "boolean"
          },
          "hasShopDelivery": {
            "type": "boolean"
          },
          "hasCityDelivery": {
            "type": "boolean"
          }
        }
      },
      "attrs" : {
        "type" : "nested",
        "properties" : {
          "attrId" : {
            "type" : "long"
          },
          "attrNameZh" : {
            "type" : "keyword"
          },
          "attrNameEn" : {
            "type" : "keyword"
          },
          "attrValueId" : {
            "type" : "long"
          },
          "attrValueNameZh" : {
            "type" : "keyword"
          },
          "attrValueNameEn" : {
            "type" : "keyword"
          }
        }
      },
      "tags" : {
        "type" : "nested",
        "properties" : {
          "tagId" : {
            "type" : "long"
          },
          "seq" : {
            "type" : "integer"
          }
        }
      },
      "brand" : {
        "type" : "nested",
        "properties" : {
          "brandId" : {
            "type" : "long"
          },
          "brandImg" : {
            "type" : "keyword"
          },
          "brandName" : {
            "type" : "keyword"
          },
          "brandNameZh" : {
            "type" : "keyword"
          },
          "brandNameEn" : {
            "type" : "keyword"
          }
        }
      },
      "code" : {
        "type" : "text",
        "fields" : {
          "keyword" : {
            "type" : "keyword",
            "ignore_above" : 256
          }
        }
      },
      "tagIds" : {
        "type" : "long"
      },
      "commentNum" : {
        "type" : "integer"
      },
      "goodReviewNum" : {
        "type" : "integer"
      },
      "createTime" : {
        "type" : "date"
      },
      "activityStartTime" : {
        "type" : "long"
      },      
      "selectedLot" : {
        "type" : "integer"
      },      
      "seckillCategoryId" : {
        "type" : "long"
      },
      "hasStock" : {
        "type" : "boolean"
      },
      "stockWarning" : {
        "type" : "long"
      },
      "imgUrls" : {
        "type" : "keyword",
        "index" : false,
        "doc_values" : false
      },
      "mainImgUrl" : {
        "type" : "text",
        "fields" : {
          "keyword" : {
            "type" : "keyword",
            "ignore_above" : 256
          }
        }
      },
      "marketPriceFee" : {
        "type" : "long"
      },
      "scoreFee" : {
        "type" : "long"
      },
      "priceFee" : {
        "type" : "long"
      },
      "stock" : {
        "type" : "integer"
      },
      "saleNum" : {
        "type" : "integer"
      },
      "actualSoldNum" : {
        "type" : "integer"
      },
      "waterSoldNum" : {
        "type" : "integer"
      },
      "sellingPointZh" : {
        "type" : "text",
        "analyzer" : "ik_max_word",
        "search_analyzer" : "ik_smart"
      },
      "sellingPointEn" : {
        "type" : "text",
        "analyzer" : "ik_max_word",
        "search_analyzer" : "ik_smart"
      },
      "partyCode" : {
        "type" : "keyword"
      },
      "modelId" : {
        "type" : "keyword"
      },
      "spuType" : {
        "type" : "integer"
      },
      "activityId" : {
        "type" : "long"
      },
      "isCompose" : {
        "type" : "integer"
      },
      "seq" : {
        "type" : "integer"
      },
      "isTop": {
        "type" : "integer"
      },
      "shopId" : {
        "type" : "long"
      },
      "shopImg" : {
        "type" : "keyword",
        "index" : false,
        "doc_values" : false
      },
      "shopName" : {
        "type" : "text",
        "analyzer" : "ik_max_word",
        "search_analyzer" : "ik_smart"
      },
      "shopType" : {
        "type" : "integer"
      },
      "shopPrimaryCategoryId" : {
        "type" : "long"
      },
      "shopCategory" : {
        "type" : "nested",
        "properties" : {
            "categoryId" : {
              "type" : "long"
            },
            "categoryNameZh" : {
              "type" : "keyword"
            },
            "categoryNameEn" : {
              "type" : "keyword"
            }
        }
      },
      "primaryCategoryId" : {
        "type" : "long"
      },
      "secondaryCategoryId" : {
        "type" : "long"
      },
      "category" : {
        "type" : "nested",
        "properties" : {
            "categoryId" : {
              "type" : "long"
            },
            "categoryNameZh" : {
              "type" : "keyword"
            },
            "categoryNameEn" : {
              "type" : "keyword"
            }
        }
      },
      "spuStatus" : {
        "type" : "integer"
      },
      "appDisplay" : {
        "type" : "boolean"
      },
      "distributionSpu": {
        "type": "boolean"
      },
      "distributionInfo": {
        "type" : "nested",
        "properties" : {
          "distributionSpuId" : {
            "type" : "long"
          },
          "state" : {
            "type" : "integer"
          },
          "awardMode" : {
            "type" : "integer"
          },
          "parentAwardSet" : {
            "type" : "integer"
          },
          "awardNumbers" : {
            "type" : "long"
          },
          "parentAwardNumbers" : {
            "type" : "long"
          }
        }
      },
      "supplierSpuType":{
        "type":"integer"
      },
      "categoryNames":{
        "type":"text"
      },
      "supplierName":{
        "type":"text",
        "analyzer":"ik_max_word",
        "search_analyzer":"ik_smart"
      },
      "supplierId":{
        "type":"long" 
      },
      "supplierDeliveryType":{
        "type":"integer"
      },
      "skuChoiceStatus":{
        "type":"integer"
      },
      "commissionSpuStatus":{
        "type":"integer"
      },
      "supplierSpuId":{
        "type":"long"
      },      
      "preSaleType":{
        "type":"integer"
      },
      "spuCode":{
        "type" : "text",
        "analyzer" : "ik_max_word",
        "search_analyzer" : "ik_smart"
      }
    }
  }
}
```
